@@ -23,7 +23,7 @@ has_exception 'Tainted' => parents => [ $class ],
    error   => 'String [_1] contains possible taint';
 
 has_exception 'TimeOut' => parents => [ $class ],
-   error   => 'Command [_1] aborted by alarm after [_2] seconds';
+   error   => 'Command [_1] timed out after [_2] seconds';
 
 has '+class' => default => $class;
 
@@ -207,7 +207,7 @@ Peter Flanigan C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2014 Peter Flanigan. All rights reserved
+Copyright (c) 2015 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
